# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'ApplicationSettingsErrorCollector',
    'ApplicationSettingsTransactionTracer',
    'ApplicationSettingsTransactionTracerExplainQueryPlan',
    'ApplicationSettingsTransactionTracerSql',
    'WorkloadEntitySearchQuery',
    'WorkloadStatusConfigAutomatic',
    'WorkloadStatusConfigAutomaticRemainingEntitiesRule',
    'WorkloadStatusConfigAutomaticRemainingEntitiesRuleRemainingEntitiesRuleRollup',
    'WorkloadStatusConfigAutomaticRule',
    'WorkloadStatusConfigAutomaticRuleNrqlQuery',
    'WorkloadStatusConfigAutomaticRuleRollup',
    'WorkloadStatusConfigStatic',
]

@pulumi.output_type
class ApplicationSettingsErrorCollector(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "expectedErrorClasses":
            suggest = "expected_error_classes"
        elif key == "expectedErrorCodes":
            suggest = "expected_error_codes"
        elif key == "ignoredErrorClasses":
            suggest = "ignored_error_classes"
        elif key == "ignoredErrorCodes":
            suggest = "ignored_error_codes"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ApplicationSettingsErrorCollector. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ApplicationSettingsErrorCollector.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ApplicationSettingsErrorCollector.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 expected_error_classes: Optional[Sequence[_builtins.str]] = None,
                 expected_error_codes: Optional[Sequence[_builtins.str]] = None,
                 ignored_error_classes: Optional[Sequence[_builtins.str]] = None,
                 ignored_error_codes: Optional[Sequence[_builtins.str]] = None):
        """
        :param Sequence[_builtins.str] expected_error_classes: A list of expected error classes.
        :param Sequence[_builtins.str] expected_error_codes: A list of expected error codes(any status code between 100-900).
        :param Sequence[_builtins.str] ignored_error_classes: A list of ignored error classes.
        :param Sequence[_builtins.str] ignored_error_codes: A list of ignored error codes(any status code between 100-900).
        """
        if expected_error_classes is not None:
            pulumi.set(__self__, "expected_error_classes", expected_error_classes)
        if expected_error_codes is not None:
            pulumi.set(__self__, "expected_error_codes", expected_error_codes)
        if ignored_error_classes is not None:
            pulumi.set(__self__, "ignored_error_classes", ignored_error_classes)
        if ignored_error_codes is not None:
            pulumi.set(__self__, "ignored_error_codes", ignored_error_codes)

    @_builtins.property
    @pulumi.getter(name="expectedErrorClasses")
    def expected_error_classes(self) -> Optional[Sequence[_builtins.str]]:
        """
        A list of expected error classes.
        """
        return pulumi.get(self, "expected_error_classes")

    @_builtins.property
    @pulumi.getter(name="expectedErrorCodes")
    def expected_error_codes(self) -> Optional[Sequence[_builtins.str]]:
        """
        A list of expected error codes(any status code between 100-900).
        """
        return pulumi.get(self, "expected_error_codes")

    @_builtins.property
    @pulumi.getter(name="ignoredErrorClasses")
    def ignored_error_classes(self) -> Optional[Sequence[_builtins.str]]:
        """
        A list of ignored error classes.
        """
        return pulumi.get(self, "ignored_error_classes")

    @_builtins.property
    @pulumi.getter(name="ignoredErrorCodes")
    def ignored_error_codes(self) -> Optional[Sequence[_builtins.str]]:
        """
        A list of ignored error codes(any status code between 100-900).
        """
        return pulumi.get(self, "ignored_error_codes")


@pulumi.output_type
class ApplicationSettingsTransactionTracer(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "explainQueryPlans":
            suggest = "explain_query_plans"
        elif key == "stackTraceThresholdValue":
            suggest = "stack_trace_threshold_value"
        elif key == "transactionThresholdType":
            suggest = "transaction_threshold_type"
        elif key == "transactionThresholdValue":
            suggest = "transaction_threshold_value"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ApplicationSettingsTransactionTracer. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ApplicationSettingsTransactionTracer.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ApplicationSettingsTransactionTracer.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 explain_query_plans: Optional[Sequence['outputs.ApplicationSettingsTransactionTracerExplainQueryPlan']] = None,
                 sql: Optional['outputs.ApplicationSettingsTransactionTracerSql'] = None,
                 stack_trace_threshold_value: Optional[_builtins.float] = None,
                 transaction_threshold_type: Optional[_builtins.str] = None,
                 transaction_threshold_value: Optional[_builtins.float] = None):
        """
        :param Sequence['ApplicationSettingsTransactionTracerExplainQueryPlanArgs'] explain_query_plans: Configuration block for query plans. Including this block enables the capture of query plans. The following arguments are supported:
        :param 'ApplicationSettingsTransactionTracerSqlArgs' sql: Configuration block for SQL logging.  Including this block enables SQL logging. The following arguments are supported:
        :param _builtins.float stack_trace_threshold_value: The response time threshold for collecting stack traces.
        :param _builtins.str transaction_threshold_type: The type of threshold for transactions. Valid values are `VALUE`,`APDEX_F`(4 times your apdex target)
        :param _builtins.float transaction_threshold_value: The threshold value for transactions(in seconds).
        """
        if explain_query_plans is not None:
            pulumi.set(__self__, "explain_query_plans", explain_query_plans)
        if sql is not None:
            pulumi.set(__self__, "sql", sql)
        if stack_trace_threshold_value is not None:
            pulumi.set(__self__, "stack_trace_threshold_value", stack_trace_threshold_value)
        if transaction_threshold_type is not None:
            pulumi.set(__self__, "transaction_threshold_type", transaction_threshold_type)
        if transaction_threshold_value is not None:
            pulumi.set(__self__, "transaction_threshold_value", transaction_threshold_value)

    @_builtins.property
    @pulumi.getter(name="explainQueryPlans")
    def explain_query_plans(self) -> Optional[Sequence['outputs.ApplicationSettingsTransactionTracerExplainQueryPlan']]:
        """
        Configuration block for query plans. Including this block enables the capture of query plans. The following arguments are supported:
        """
        return pulumi.get(self, "explain_query_plans")

    @_builtins.property
    @pulumi.getter
    def sql(self) -> Optional['outputs.ApplicationSettingsTransactionTracerSql']:
        """
        Configuration block for SQL logging.  Including this block enables SQL logging. The following arguments are supported:
        """
        return pulumi.get(self, "sql")

    @_builtins.property
    @pulumi.getter(name="stackTraceThresholdValue")
    def stack_trace_threshold_value(self) -> Optional[_builtins.float]:
        """
        The response time threshold for collecting stack traces.
        """
        return pulumi.get(self, "stack_trace_threshold_value")

    @_builtins.property
    @pulumi.getter(name="transactionThresholdType")
    def transaction_threshold_type(self) -> Optional[_builtins.str]:
        """
        The type of threshold for transactions. Valid values are `VALUE`,`APDEX_F`(4 times your apdex target)
        """
        return pulumi.get(self, "transaction_threshold_type")

    @_builtins.property
    @pulumi.getter(name="transactionThresholdValue")
    def transaction_threshold_value(self) -> Optional[_builtins.float]:
        """
        The threshold value for transactions(in seconds).
        """
        return pulumi.get(self, "transaction_threshold_value")


@pulumi.output_type
class ApplicationSettingsTransactionTracerExplainQueryPlan(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "queryPlanThresholdType":
            suggest = "query_plan_threshold_type"
        elif key == "queryPlanThresholdValue":
            suggest = "query_plan_threshold_value"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ApplicationSettingsTransactionTracerExplainQueryPlan. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ApplicationSettingsTransactionTracerExplainQueryPlan.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ApplicationSettingsTransactionTracerExplainQueryPlan.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 query_plan_threshold_type: Optional[_builtins.str] = None,
                 query_plan_threshold_value: Optional[_builtins.float] = None):
        """
        :param _builtins.str query_plan_threshold_type: The type of threshold for query plans. Valid values are `VALUE`,`APDEX_F`(4 times your apdex target)
        :param _builtins.float query_plan_threshold_value: The response time threshold for capturing query plans(in seconds).
        """
        if query_plan_threshold_type is not None:
            pulumi.set(__self__, "query_plan_threshold_type", query_plan_threshold_type)
        if query_plan_threshold_value is not None:
            pulumi.set(__self__, "query_plan_threshold_value", query_plan_threshold_value)

    @_builtins.property
    @pulumi.getter(name="queryPlanThresholdType")
    def query_plan_threshold_type(self) -> Optional[_builtins.str]:
        """
        The type of threshold for query plans. Valid values are `VALUE`,`APDEX_F`(4 times your apdex target)
        """
        return pulumi.get(self, "query_plan_threshold_type")

    @_builtins.property
    @pulumi.getter(name="queryPlanThresholdValue")
    def query_plan_threshold_value(self) -> Optional[_builtins.float]:
        """
        The response time threshold for capturing query plans(in seconds).
        """
        return pulumi.get(self, "query_plan_threshold_value")


@pulumi.output_type
class ApplicationSettingsTransactionTracerSql(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "recordSql":
            suggest = "record_sql"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ApplicationSettingsTransactionTracerSql. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ApplicationSettingsTransactionTracerSql.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ApplicationSettingsTransactionTracerSql.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 record_sql: _builtins.str):
        """
        :param _builtins.str record_sql: The level of SQL recording. Valid values ar `OBFUSCATED`,`OFF`,`RAW` (Mandatory attribute when `sql` block is provided).
        """
        pulumi.set(__self__, "record_sql", record_sql)

    @_builtins.property
    @pulumi.getter(name="recordSql")
    def record_sql(self) -> _builtins.str:
        """
        The level of SQL recording. Valid values ar `OBFUSCATED`,`OFF`,`RAW` (Mandatory attribute when `sql` block is provided).
        """
        return pulumi.get(self, "record_sql")


@pulumi.output_type
class WorkloadEntitySearchQuery(dict):
    def __init__(__self__, *,
                 query: _builtins.str):
        """
        :param _builtins.str query: A valid entity search query; empty, and null values are considered invalid.
        """
        pulumi.set(__self__, "query", query)

    @_builtins.property
    @pulumi.getter
    def query(self) -> _builtins.str:
        """
        A valid entity search query; empty, and null values are considered invalid.
        """
        return pulumi.get(self, "query")


@pulumi.output_type
class WorkloadStatusConfigAutomatic(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "remainingEntitiesRule":
            suggest = "remaining_entities_rule"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in WorkloadStatusConfigAutomatic. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        WorkloadStatusConfigAutomatic.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        WorkloadStatusConfigAutomatic.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 enabled: _builtins.bool,
                 remaining_entities_rule: Optional['outputs.WorkloadStatusConfigAutomaticRemainingEntitiesRule'] = None,
                 rules: Optional[Sequence['outputs.WorkloadStatusConfigAutomaticRule']] = None):
        """
        :param _builtins.bool enabled: Whether the automatic status configuration is enabled or not.
        :param 'WorkloadStatusConfigAutomaticRemainingEntitiesRuleArgs' remaining_entities_rule: An additional meta-rule that can consider all entities that haven't been evaluated by any other rule.
        :param Sequence['WorkloadStatusConfigAutomaticRuleArgs'] rules: A list of rules.
        """
        pulumi.set(__self__, "enabled", enabled)
        if remaining_entities_rule is not None:
            pulumi.set(__self__, "remaining_entities_rule", remaining_entities_rule)
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> _builtins.bool:
        """
        Whether the automatic status configuration is enabled or not.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter(name="remainingEntitiesRule")
    def remaining_entities_rule(self) -> Optional['outputs.WorkloadStatusConfigAutomaticRemainingEntitiesRule']:
        """
        An additional meta-rule that can consider all entities that haven't been evaluated by any other rule.
        """
        return pulumi.get(self, "remaining_entities_rule")

    @_builtins.property
    @pulumi.getter
    def rules(self) -> Optional[Sequence['outputs.WorkloadStatusConfigAutomaticRule']]:
        """
        A list of rules.
        """
        return pulumi.get(self, "rules")


@pulumi.output_type
class WorkloadStatusConfigAutomaticRemainingEntitiesRule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "remainingEntitiesRuleRollup":
            suggest = "remaining_entities_rule_rollup"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in WorkloadStatusConfigAutomaticRemainingEntitiesRule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        WorkloadStatusConfigAutomaticRemainingEntitiesRule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        WorkloadStatusConfigAutomaticRemainingEntitiesRule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 remaining_entities_rule_rollup: 'outputs.WorkloadStatusConfigAutomaticRemainingEntitiesRuleRemainingEntitiesRuleRollup'):
        """
        :param 'WorkloadStatusConfigAutomaticRemainingEntitiesRuleRemainingEntitiesRuleRollupArgs' remaining_entities_rule_rollup: The input object used to represent a rollup strategy.
        """
        pulumi.set(__self__, "remaining_entities_rule_rollup", remaining_entities_rule_rollup)

    @_builtins.property
    @pulumi.getter(name="remainingEntitiesRuleRollup")
    def remaining_entities_rule_rollup(self) -> 'outputs.WorkloadStatusConfigAutomaticRemainingEntitiesRuleRemainingEntitiesRuleRollup':
        """
        The input object used to represent a rollup strategy.
        """
        return pulumi.get(self, "remaining_entities_rule_rollup")


@pulumi.output_type
class WorkloadStatusConfigAutomaticRemainingEntitiesRuleRemainingEntitiesRuleRollup(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "groupBy":
            suggest = "group_by"
        elif key == "thresholdType":
            suggest = "threshold_type"
        elif key == "thresholdValue":
            suggest = "threshold_value"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in WorkloadStatusConfigAutomaticRemainingEntitiesRuleRemainingEntitiesRuleRollup. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        WorkloadStatusConfigAutomaticRemainingEntitiesRuleRemainingEntitiesRuleRollup.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        WorkloadStatusConfigAutomaticRemainingEntitiesRuleRemainingEntitiesRuleRollup.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 group_by: _builtins.str,
                 strategy: _builtins.str,
                 threshold_type: Optional[_builtins.str] = None,
                 threshold_value: Optional[_builtins.int] = None):
        """
        :param _builtins.str group_by: The grouping to be applied to the remaining entities.
        :param _builtins.str strategy: The rollup strategy that is applied to a group of entities.
        :param _builtins.str threshold_type: Type of threshold defined for the rule. This is an optional field that only applies when strategy is WORST_STATUS_WINS. Use a threshold to roll up the worst status only after a certain amount of entities are not operational.
        :param _builtins.int threshold_value: Threshold value defined for the rule. This optional field is used in combination with thresholdType. If the threshold type is null, the threshold value will be ignored.
        """
        pulumi.set(__self__, "group_by", group_by)
        pulumi.set(__self__, "strategy", strategy)
        if threshold_type is not None:
            pulumi.set(__self__, "threshold_type", threshold_type)
        if threshold_value is not None:
            pulumi.set(__self__, "threshold_value", threshold_value)

    @_builtins.property
    @pulumi.getter(name="groupBy")
    def group_by(self) -> _builtins.str:
        """
        The grouping to be applied to the remaining entities.
        """
        return pulumi.get(self, "group_by")

    @_builtins.property
    @pulumi.getter
    def strategy(self) -> _builtins.str:
        """
        The rollup strategy that is applied to a group of entities.
        """
        return pulumi.get(self, "strategy")

    @_builtins.property
    @pulumi.getter(name="thresholdType")
    def threshold_type(self) -> Optional[_builtins.str]:
        """
        Type of threshold defined for the rule. This is an optional field that only applies when strategy is WORST_STATUS_WINS. Use a threshold to roll up the worst status only after a certain amount of entities are not operational.
        """
        return pulumi.get(self, "threshold_type")

    @_builtins.property
    @pulumi.getter(name="thresholdValue")
    def threshold_value(self) -> Optional[_builtins.int]:
        """
        Threshold value defined for the rule. This optional field is used in combination with thresholdType. If the threshold type is null, the threshold value will be ignored.
        """
        return pulumi.get(self, "threshold_value")


@pulumi.output_type
class WorkloadStatusConfigAutomaticRule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "entityGuids":
            suggest = "entity_guids"
        elif key == "nrqlQueries":
            suggest = "nrql_queries"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in WorkloadStatusConfigAutomaticRule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        WorkloadStatusConfigAutomaticRule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        WorkloadStatusConfigAutomaticRule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 rollup: 'outputs.WorkloadStatusConfigAutomaticRuleRollup',
                 entity_guids: Optional[Sequence[_builtins.str]] = None,
                 nrql_queries: Optional[Sequence['outputs.WorkloadStatusConfigAutomaticRuleNrqlQuery']] = None):
        """
        :param 'WorkloadStatusConfigAutomaticRuleRollupArgs' rollup: The input object used to represent a rollup strategy. See Nested rollup blocks below for details.
        :param Sequence[_builtins.str] entity_guids: A list of entity GUIDs composing the rule. At least one of `entity_guids` or `nrql_query` must be defined.
        :param Sequence['WorkloadStatusConfigAutomaticRuleNrqlQueryArgs'] nrql_queries: A list of entity search queries used to retrieve the entities that compose the rule. See Nested nrql_query blocks below for details. At least one of `entity_guids` or `nrql_query` must be defined.
        """
        pulumi.set(__self__, "rollup", rollup)
        if entity_guids is not None:
            pulumi.set(__self__, "entity_guids", entity_guids)
        if nrql_queries is not None:
            pulumi.set(__self__, "nrql_queries", nrql_queries)

    @_builtins.property
    @pulumi.getter
    def rollup(self) -> 'outputs.WorkloadStatusConfigAutomaticRuleRollup':
        """
        The input object used to represent a rollup strategy. See Nested rollup blocks below for details.
        """
        return pulumi.get(self, "rollup")

    @_builtins.property
    @pulumi.getter(name="entityGuids")
    def entity_guids(self) -> Optional[Sequence[_builtins.str]]:
        """
        A list of entity GUIDs composing the rule. At least one of `entity_guids` or `nrql_query` must be defined.
        """
        return pulumi.get(self, "entity_guids")

    @_builtins.property
    @pulumi.getter(name="nrqlQueries")
    def nrql_queries(self) -> Optional[Sequence['outputs.WorkloadStatusConfigAutomaticRuleNrqlQuery']]:
        """
        A list of entity search queries used to retrieve the entities that compose the rule. See Nested nrql_query blocks below for details. At least one of `entity_guids` or `nrql_query` must be defined.
        """
        return pulumi.get(self, "nrql_queries")


@pulumi.output_type
class WorkloadStatusConfigAutomaticRuleNrqlQuery(dict):
    def __init__(__self__, *,
                 query: _builtins.str):
        """
        :param _builtins.str query: The entity search query that is used to perform the search of a group of entities.
        """
        pulumi.set(__self__, "query", query)

    @_builtins.property
    @pulumi.getter
    def query(self) -> _builtins.str:
        """
        The entity search query that is used to perform the search of a group of entities.
        """
        return pulumi.get(self, "query")


@pulumi.output_type
class WorkloadStatusConfigAutomaticRuleRollup(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "thresholdType":
            suggest = "threshold_type"
        elif key == "thresholdValue":
            suggest = "threshold_value"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in WorkloadStatusConfigAutomaticRuleRollup. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        WorkloadStatusConfigAutomaticRuleRollup.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        WorkloadStatusConfigAutomaticRuleRollup.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 strategy: _builtins.str,
                 threshold_type: Optional[_builtins.str] = None,
                 threshold_value: Optional[_builtins.int] = None):
        """
        :param _builtins.str strategy: The rollup strategy that is applied to a group of entities.
        :param _builtins.str threshold_type: Type of threshold defined for the rule. This is an optional field that only applies when strategy is WORST_STATUS_WINS. Use a threshold to roll up the worst status only after a certain amount of entities are not operational.
        :param _builtins.int threshold_value: Threshold value defined for the rule. This optional field is used in combination with thresholdType. If the threshold type is null, the threshold value will be ignored.
        """
        pulumi.set(__self__, "strategy", strategy)
        if threshold_type is not None:
            pulumi.set(__self__, "threshold_type", threshold_type)
        if threshold_value is not None:
            pulumi.set(__self__, "threshold_value", threshold_value)

    @_builtins.property
    @pulumi.getter
    def strategy(self) -> _builtins.str:
        """
        The rollup strategy that is applied to a group of entities.
        """
        return pulumi.get(self, "strategy")

    @_builtins.property
    @pulumi.getter(name="thresholdType")
    def threshold_type(self) -> Optional[_builtins.str]:
        """
        Type of threshold defined for the rule. This is an optional field that only applies when strategy is WORST_STATUS_WINS. Use a threshold to roll up the worst status only after a certain amount of entities are not operational.
        """
        return pulumi.get(self, "threshold_type")

    @_builtins.property
    @pulumi.getter(name="thresholdValue")
    def threshold_value(self) -> Optional[_builtins.int]:
        """
        Threshold value defined for the rule. This optional field is used in combination with thresholdType. If the threshold type is null, the threshold value will be ignored.
        """
        return pulumi.get(self, "threshold_value")


@pulumi.output_type
class WorkloadStatusConfigStatic(dict):
    def __init__(__self__, *,
                 enabled: _builtins.bool,
                 status: _builtins.str,
                 description: Optional[_builtins.str] = None,
                 summary: Optional[_builtins.str] = None):
        """
        :param _builtins.bool enabled: Whether the static status configuration is enabled or not.
        :param _builtins.str status: The status of the workload.
        :param _builtins.str description: Relevant information about the workload.
        :param _builtins.str summary: A short description of the status of the workload.
        """
        pulumi.set(__self__, "enabled", enabled)
        pulumi.set(__self__, "status", status)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if summary is not None:
            pulumi.set(__self__, "summary", summary)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> _builtins.bool:
        """
        Whether the static status configuration is enabled or not.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        The status of the workload.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[_builtins.str]:
        """
        Relevant information about the workload.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def summary(self) -> Optional[_builtins.str]:
        """
        A short description of the status of the workload.
        """
        return pulumi.get(self, "summary")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetGroupResult',
    'AwaitableGetGroupResult',
    'get_group',
    'get_group_output',
]

@pulumi.output_type
class GetGroupResult:
    """
    A collection of values returned by getGroup.
    """
    def __init__(__self__, authentication_domain_id=None, id=None, name=None, user_ids=None):
        if authentication_domain_id and not isinstance(authentication_domain_id, str):
            raise TypeError("Expected argument 'authentication_domain_id' to be a str")
        pulumi.set(__self__, "authentication_domain_id", authentication_domain_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if user_ids and not isinstance(user_ids, list):
            raise TypeError("Expected argument 'user_ids' to be a list")
        pulumi.set(__self__, "user_ids", user_ids)

    @_builtins.property
    @pulumi.getter(name="authenticationDomainId")
    def authentication_domain_id(self) -> _builtins.str:
        return pulumi.get(self, "authentication_domain_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of the fetched matching group.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="userIds")
    def user_ids(self) -> Sequence[_builtins.str]:
        """
        IDs of users who belong to the group. In the absence of any users in the group, the value of this attribute would be an empty list.
        """
        return pulumi.get(self, "user_ids")


class AwaitableGetGroupResult(GetGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGroupResult(
            authentication_domain_id=self.authentication_domain_id,
            id=self.id,
            name=self.name,
            user_ids=self.user_ids)


def get_group(authentication_domain_id: Optional[_builtins.str] = None,
              name: Optional[_builtins.str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGroupResult:
    """
    The `Group` data source helps search for a group by its name and retrieve the ID of the matching group and other associated attributes.

    ## Example Usage

    The below example illustrates fetching the ID of a group (and IDs of users who belong to the group, if any) using the required arguments.

    ```python
    import pulumi
    import pulumi_newrelic as newrelic

    foo = newrelic.get_authentication_domain(name="Test Authentication Domain")
    foo_get_group = newrelic.get_group(authentication_domain_id=foo.id,
        name="Test Group")
    ```

    ## Additional Examples

    The following example demonstrates utilizing attributes exported by this data source.

    In order to directly reference the attributes `id` and `user_ids` from this data source, you can use the syntax `data.newrelic_group.foo.id` and `data.newrelic_group.foo.user_ids`, respectively. However, if you need to assign these values to local variables and perform further processing (such as conditionally formatting the `user_ids` attribute as shown in the example below), consider using the provided configuration. These variables can then be accessed elsewhere using the syntax `local.id` and `local.user_id`, respectively.

    ```python
    import pulumi
    import pulumi_newrelic as newrelic
    import pulumi_std as std

    foo = newrelic.get_authentication_domain(name="Test Authentication Domain")
    foo_get_group = newrelic.get_group(authentication_domain_id=foo.id,
        name="Test Group")
    id = foo_get_group.id
    user_ids = len(foo_get_group.user_ids).apply(lambda length: std.join(separator=", ",
        input=foo_get_group.user_ids).result if length > 0 else "")
    ```


    :param _builtins.str authentication_domain_id: The ID of the authentication domain the group to be searched for belongs to.
    :param _builtins.str name: The name of the group to search for.
           
           > **NOTE** The ID of an authentication domain can be retrieved using its name, via the data source `get_authentication_domain`, as shown in the example above. Head over to the documentation of this data source for more details and examples.
    """
    __args__ = dict()
    __args__['authenticationDomainId'] = authentication_domain_id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('newrelic:index/getGroup:getGroup', __args__, opts=opts, typ=GetGroupResult).value

    return AwaitableGetGroupResult(
        authentication_domain_id=pulumi.get(__ret__, 'authentication_domain_id'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        user_ids=pulumi.get(__ret__, 'user_ids'))
def get_group_output(authentication_domain_id: Optional[pulumi.Input[_builtins.str]] = None,
                     name: Optional[pulumi.Input[_builtins.str]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGroupResult]:
    """
    The `Group` data source helps search for a group by its name and retrieve the ID of the matching group and other associated attributes.

    ## Example Usage

    The below example illustrates fetching the ID of a group (and IDs of users who belong to the group, if any) using the required arguments.

    ```python
    import pulumi
    import pulumi_newrelic as newrelic

    foo = newrelic.get_authentication_domain(name="Test Authentication Domain")
    foo_get_group = newrelic.get_group(authentication_domain_id=foo.id,
        name="Test Group")
    ```

    ## Additional Examples

    The following example demonstrates utilizing attributes exported by this data source.

    In order to directly reference the attributes `id` and `user_ids` from this data source, you can use the syntax `data.newrelic_group.foo.id` and `data.newrelic_group.foo.user_ids`, respectively. However, if you need to assign these values to local variables and perform further processing (such as conditionally formatting the `user_ids` attribute as shown in the example below), consider using the provided configuration. These variables can then be accessed elsewhere using the syntax `local.id` and `local.user_id`, respectively.

    ```python
    import pulumi
    import pulumi_newrelic as newrelic
    import pulumi_std as std

    foo = newrelic.get_authentication_domain(name="Test Authentication Domain")
    foo_get_group = newrelic.get_group(authentication_domain_id=foo.id,
        name="Test Group")
    id = foo_get_group.id
    user_ids = len(foo_get_group.user_ids).apply(lambda length: std.join(separator=", ",
        input=foo_get_group.user_ids).result if length > 0 else "")
    ```


    :param _builtins.str authentication_domain_id: The ID of the authentication domain the group to be searched for belongs to.
    :param _builtins.str name: The name of the group to search for.
           
           > **NOTE** The ID of an authentication domain can be retrieved using its name, via the data source `get_authentication_domain`, as shown in the example above. Head over to the documentation of this data source for more details and examples.
    """
    __args__ = dict()
    __args__['authenticationDomainId'] = authentication_domain_id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('newrelic:index/getGroup:getGroup', __args__, opts=opts, typ=GetGroupResult)
    return __ret__.apply(lambda __response__: GetGroupResult(
        authentication_domain_id=pulumi.get(__response__, 'authentication_domain_id'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        user_ids=pulumi.get(__response__, 'user_ids')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['MonitorDowntimeArgs', 'MonitorDowntime']

@pulumi.input_type
class MonitorDowntimeArgs:
    def __init__(__self__, *,
                 end_time: pulumi.Input[_builtins.str],
                 mode: pulumi.Input[_builtins.str],
                 start_time: pulumi.Input[_builtins.str],
                 time_zone: pulumi.Input[_builtins.str],
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 end_repeat: Optional[pulumi.Input['MonitorDowntimeEndRepeatArgs']] = None,
                 frequency: Optional[pulumi.Input['MonitorDowntimeFrequencyArgs']] = None,
                 maintenance_days: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 monitor_guids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a MonitorDowntime resource.
        :param pulumi.Input[_builtins.str] end_time: A datetime stamp signifying the end of the Monitor Downtime.
        :param pulumi.Input[_builtins.str] mode: An identifier of the type of Monitor Downtime to be created.
        :param pulumi.Input[_builtins.str] start_time: A datetime stamp signifying the start of the Monitor Downtime.
        :param pulumi.Input[_builtins.str] time_zone: The timezone that applies to the Monitor Downtime schedule.
        :param pulumi.Input[_builtins.str] account_id: The ID of the New Relic account in which the Monitor Downtime shall be created. Defaults to the `account_id` in the provider{} configuration if not specified.
        :param pulumi.Input['MonitorDowntimeEndRepeatArgs'] end_repeat: A specification of when the Monitor Downtime should end its repeat cycle, by number of occurrences or date.
        :param pulumi.Input['MonitorDowntimeFrequencyArgs'] frequency: Configuration options for which days of the month a monitor downtime will occur
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] maintenance_days: A list of maintenance days to be included with the created weekly Monitor Downtime.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] monitor_guids: A list of GUIDs of monitors, to which the created Monitor Downtime shall be applied.
        :param pulumi.Input[_builtins.str] name: A name to identify the Monitor Downtime to be created.
        """
        pulumi.set(__self__, "end_time", end_time)
        pulumi.set(__self__, "mode", mode)
        pulumi.set(__self__, "start_time", start_time)
        pulumi.set(__self__, "time_zone", time_zone)
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if end_repeat is not None:
            pulumi.set(__self__, "end_repeat", end_repeat)
        if frequency is not None:
            pulumi.set(__self__, "frequency", frequency)
        if maintenance_days is not None:
            pulumi.set(__self__, "maintenance_days", maintenance_days)
        if monitor_guids is not None:
            pulumi.set(__self__, "monitor_guids", monitor_guids)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="endTime")
    def end_time(self) -> pulumi.Input[_builtins.str]:
        """
        A datetime stamp signifying the end of the Monitor Downtime.
        """
        return pulumi.get(self, "end_time")

    @end_time.setter
    def end_time(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "end_time", value)

    @_builtins.property
    @pulumi.getter
    def mode(self) -> pulumi.Input[_builtins.str]:
        """
        An identifier of the type of Monitor Downtime to be created.
        """
        return pulumi.get(self, "mode")

    @mode.setter
    def mode(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "mode", value)

    @_builtins.property
    @pulumi.getter(name="startTime")
    def start_time(self) -> pulumi.Input[_builtins.str]:
        """
        A datetime stamp signifying the start of the Monitor Downtime.
        """
        return pulumi.get(self, "start_time")

    @start_time.setter
    def start_time(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "start_time", value)

    @_builtins.property
    @pulumi.getter(name="timeZone")
    def time_zone(self) -> pulumi.Input[_builtins.str]:
        """
        The timezone that applies to the Monitor Downtime schedule.
        """
        return pulumi.get(self, "time_zone")

    @time_zone.setter
    def time_zone(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "time_zone", value)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the New Relic account in which the Monitor Downtime shall be created. Defaults to the `account_id` in the provider{} configuration if not specified.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="endRepeat")
    def end_repeat(self) -> Optional[pulumi.Input['MonitorDowntimeEndRepeatArgs']]:
        """
        A specification of when the Monitor Downtime should end its repeat cycle, by number of occurrences or date.
        """
        return pulumi.get(self, "end_repeat")

    @end_repeat.setter
    def end_repeat(self, value: Optional[pulumi.Input['MonitorDowntimeEndRepeatArgs']]):
        pulumi.set(self, "end_repeat", value)

    @_builtins.property
    @pulumi.getter
    def frequency(self) -> Optional[pulumi.Input['MonitorDowntimeFrequencyArgs']]:
        """
        Configuration options for which days of the month a monitor downtime will occur
        """
        return pulumi.get(self, "frequency")

    @frequency.setter
    def frequency(self, value: Optional[pulumi.Input['MonitorDowntimeFrequencyArgs']]):
        pulumi.set(self, "frequency", value)

    @_builtins.property
    @pulumi.getter(name="maintenanceDays")
    def maintenance_days(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of maintenance days to be included with the created weekly Monitor Downtime.
        """
        return pulumi.get(self, "maintenance_days")

    @maintenance_days.setter
    def maintenance_days(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "maintenance_days", value)

    @_builtins.property
    @pulumi.getter(name="monitorGuids")
    def monitor_guids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of GUIDs of monitors, to which the created Monitor Downtime shall be applied.
        """
        return pulumi.get(self, "monitor_guids")

    @monitor_guids.setter
    def monitor_guids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "monitor_guids", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A name to identify the Monitor Downtime to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _MonitorDowntimeState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 end_repeat: Optional[pulumi.Input['MonitorDowntimeEndRepeatArgs']] = None,
                 end_time: Optional[pulumi.Input[_builtins.str]] = None,
                 frequency: Optional[pulumi.Input['MonitorDowntimeFrequencyArgs']] = None,
                 maintenance_days: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 mode: Optional[pulumi.Input[_builtins.str]] = None,
                 monitor_guids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 start_time: Optional[pulumi.Input[_builtins.str]] = None,
                 time_zone: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering MonitorDowntime resources.
        :param pulumi.Input[_builtins.str] account_id: The ID of the New Relic account in which the Monitor Downtime shall be created. Defaults to the `account_id` in the provider{} configuration if not specified.
        :param pulumi.Input['MonitorDowntimeEndRepeatArgs'] end_repeat: A specification of when the Monitor Downtime should end its repeat cycle, by number of occurrences or date.
        :param pulumi.Input[_builtins.str] end_time: A datetime stamp signifying the end of the Monitor Downtime.
        :param pulumi.Input['MonitorDowntimeFrequencyArgs'] frequency: Configuration options for which days of the month a monitor downtime will occur
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] maintenance_days: A list of maintenance days to be included with the created weekly Monitor Downtime.
        :param pulumi.Input[_builtins.str] mode: An identifier of the type of Monitor Downtime to be created.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] monitor_guids: A list of GUIDs of monitors, to which the created Monitor Downtime shall be applied.
        :param pulumi.Input[_builtins.str] name: A name to identify the Monitor Downtime to be created.
        :param pulumi.Input[_builtins.str] start_time: A datetime stamp signifying the start of the Monitor Downtime.
        :param pulumi.Input[_builtins.str] time_zone: The timezone that applies to the Monitor Downtime schedule.
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if end_repeat is not None:
            pulumi.set(__self__, "end_repeat", end_repeat)
        if end_time is not None:
            pulumi.set(__self__, "end_time", end_time)
        if frequency is not None:
            pulumi.set(__self__, "frequency", frequency)
        if maintenance_days is not None:
            pulumi.set(__self__, "maintenance_days", maintenance_days)
        if mode is not None:
            pulumi.set(__self__, "mode", mode)
        if monitor_guids is not None:
            pulumi.set(__self__, "monitor_guids", monitor_guids)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if start_time is not None:
            pulumi.set(__self__, "start_time", start_time)
        if time_zone is not None:
            pulumi.set(__self__, "time_zone", time_zone)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the New Relic account in which the Monitor Downtime shall be created. Defaults to the `account_id` in the provider{} configuration if not specified.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="endRepeat")
    def end_repeat(self) -> Optional[pulumi.Input['MonitorDowntimeEndRepeatArgs']]:
        """
        A specification of when the Monitor Downtime should end its repeat cycle, by number of occurrences or date.
        """
        return pulumi.get(self, "end_repeat")

    @end_repeat.setter
    def end_repeat(self, value: Optional[pulumi.Input['MonitorDowntimeEndRepeatArgs']]):
        pulumi.set(self, "end_repeat", value)

    @_builtins.property
    @pulumi.getter(name="endTime")
    def end_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A datetime stamp signifying the end of the Monitor Downtime.
        """
        return pulumi.get(self, "end_time")

    @end_time.setter
    def end_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "end_time", value)

    @_builtins.property
    @pulumi.getter
    def frequency(self) -> Optional[pulumi.Input['MonitorDowntimeFrequencyArgs']]:
        """
        Configuration options for which days of the month a monitor downtime will occur
        """
        return pulumi.get(self, "frequency")

    @frequency.setter
    def frequency(self, value: Optional[pulumi.Input['MonitorDowntimeFrequencyArgs']]):
        pulumi.set(self, "frequency", value)

    @_builtins.property
    @pulumi.getter(name="maintenanceDays")
    def maintenance_days(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of maintenance days to be included with the created weekly Monitor Downtime.
        """
        return pulumi.get(self, "maintenance_days")

    @maintenance_days.setter
    def maintenance_days(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "maintenance_days", value)

    @_builtins.property
    @pulumi.getter
    def mode(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        An identifier of the type of Monitor Downtime to be created.
        """
        return pulumi.get(self, "mode")

    @mode.setter
    def mode(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mode", value)

    @_builtins.property
    @pulumi.getter(name="monitorGuids")
    def monitor_guids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of GUIDs of monitors, to which the created Monitor Downtime shall be applied.
        """
        return pulumi.get(self, "monitor_guids")

    @monitor_guids.setter
    def monitor_guids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "monitor_guids", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A name to identify the Monitor Downtime to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="startTime")
    def start_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A datetime stamp signifying the start of the Monitor Downtime.
        """
        return pulumi.get(self, "start_time")

    @start_time.setter
    def start_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "start_time", value)

    @_builtins.property
    @pulumi.getter(name="timeZone")
    def time_zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The timezone that applies to the Monitor Downtime schedule.
        """
        return pulumi.get(self, "time_zone")

    @time_zone.setter
    def time_zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "time_zone", value)


@pulumi.type_token("newrelic:index/monitorDowntime:MonitorDowntime")
class MonitorDowntime(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 end_repeat: Optional[pulumi.Input[Union['MonitorDowntimeEndRepeatArgs', 'MonitorDowntimeEndRepeatArgsDict']]] = None,
                 end_time: Optional[pulumi.Input[_builtins.str]] = None,
                 frequency: Optional[pulumi.Input[Union['MonitorDowntimeFrequencyArgs', 'MonitorDowntimeFrequencyArgsDict']]] = None,
                 maintenance_days: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 mode: Optional[pulumi.Input[_builtins.str]] = None,
                 monitor_guids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 start_time: Optional[pulumi.Input[_builtins.str]] = None,
                 time_zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Use this resource to create, update, and delete [Monitor Downtimes](https://docs.newrelic.com/docs/synthetics/synthetic-monitoring/using-monitors/monitor-downtimes-disable-monitoring-during-scheduled-maintenance-times/) in New Relic.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.MonitorDowntime("foo",
            name="Sample Monitor Downtime",
            monitor_guids=[
                "<GUID-1>",
                "<GUID-2>",
            ],
            mode="WEEKLY",
            start_time="2023-11-30T10:30:00",
            end_time="2023-12-10T02:45:30",
            time_zone="Asia/Kolkata",
            end_repeat={
                "on_date": "2023-12-20",
            },
            maintenance_days=[
                "FRIDAY",
                "SATURDAY",
            ])
        ```
        Monitor Downtimes are of four types; **one-time**, **daily**, **weekly** and **monthly**. For more details on each type and the right arguments that go with them, check out the argument reference and examples sections below.

        ## Examples

        ### One-Time Monitor Downtime

        The below example illustrates creating a **one-time** monitor downtime.

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        sample_one_time_newrelic_monitor_downtime = newrelic.MonitorDowntime("sample_one_time_newrelic_monitor_downtime",
            name="Sample One Time Monitor Downtime",
            monitor_guids=[
                "<GUID-1>",
                "<GUID-2>",
            ],
            mode="ONE_TIME",
            start_time="2023-12-04T10:15:00",
            end_time="2024-01-04T16:24:30",
            time_zone="America/Los_Angeles")
        ```

        ### Daily Monitor Downtime

        The below example illustrates creating a **daily** monitor downtime.

        Note that `end_repeat` has been specified in the configuration; however, this is optional, in accordance with the rules of `end_repeat` specified in the argument reference section above. This example uses the `on_date` nested argument of `end_repeat`, however, the other nested argument, `on_repeat` may also be used _instead_, as you may see in some of the other examples below; though both `on_date` and `on_repeat` cannot be specified together, as they are mutually exclusive.

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        sample_daily_newrelic_monitor_downtime = newrelic.MonitorDowntime("sample_daily_newrelic_monitor_downtime",
            name="Sample Daily Monitor Downtime",
            monitor_guids=[
                "<GUID-1>",
                "<GUID-2>",
            ],
            mode="DAILY",
            start_time="2023-12-04T18:15:00",
            end_time="2024-01-04T07:15:00",
            end_repeat={
                "on_date": "2023-12-25",
            },
            time_zone="Asia/Kolkata")
        ```

        ### Weekly Monitor Downtime

        The below example illustrates creating a **weekly** monitor downtime.

        Note that `maintenance_days` has been specified in the configuration as it is required with weekly monitor downtimes; and `end_repeat` has not been specified as it is optional, all in accordance with the rules of these arguments specified in the argument reference section above.

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        sample_weekly_newrelic_monitor_downtime = newrelic.MonitorDowntime("sample_weekly_newrelic_monitor_downtime",
            name="Sample Weekly Monitor Downtime",
            monitor_guids=[
                "<GUID-1>",
                "<GUID-2>",
            ],
            mode="WEEKLY",
            start_time="2023-12-04T14:15:00",
            end_time="2024-01-04T23:55:00",
            time_zone="US/Hawaii",
            maintenance_days=[
                "SATURDAY",
                "SUNDAY",
            ])
        ```

        ### Monthly Monitor Downtime

        The below example illustrates creating a **monthly** monitor downtime.

        Note that `frequency` has been specified in the configuration as it is required with monthly monitor downtimes, and `end_repeat` has been specified too, though it is optional. `frequency` has been specified with `days_of_week` comprising both of its nested arguments, `ordinal_day_of_month` and `week_day`; all in accordance with the rules of these arguments specified in the argument reference section above.

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        sample_monthly_newrelic_monitor_downtime = newrelic.MonitorDowntime("sample_monthly_newrelic_monitor_downtime",
            name="Sample Monthly Monitor Downtime",
            monitor_guids=[
                "<GUID-1>",
                "<GUID-2>",
            ],
            mode="MONTHLY",
            start_time="2023-12-04T07:15:00",
            end_time="2024-01-04T19:15:00",
            end_repeat={
                "on_repeat": 6,
            },
            time_zone="Europe/Dublin",
            frequency={
                "days_of_week": {
                    "ordinal_day_of_month": "SECOND",
                    "week_day": "SATURDAY",
                },
            })
        ```
        However, the `frequency` block in monthly monitor downtimes may also be specified with its other nested argument, `days_of_month`, as shown in the example below - though both `days_of_month` and `days_of_week` cannot be specified together, as they are mutually exclusive.
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        sample_monthly_newrelic_monitor_downtime = newrelic.MonitorDowntime("sample_monthly_newrelic_monitor_downtime",
            name="Sample Monthly Monitor Downtime",
            monitor_guids=[
                "<GUID-1>",
                "<GUID-2>",
            ],
            mode="MONTHLY",
            start_time="2023-12-04T07:15:00",
            end_time="2024-01-04T19:15:00",
            end_repeat={
                "on_repeat": 6,
            },
            time_zone="Europe/Dublin",
            frequency={
                "days_of_months": [
                    3,
                    6,
                    14,
                    23,
                ],
            })
        ```

        ## Import

        A monitor downtime can be imported into Terraform configuration using its `guid`, i.e.

        bash

        ```sh
        $ pulumi import newrelic:index/monitorDowntime:MonitorDowntime monitor <guid>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: The ID of the New Relic account in which the Monitor Downtime shall be created. Defaults to the `account_id` in the provider{} configuration if not specified.
        :param pulumi.Input[Union['MonitorDowntimeEndRepeatArgs', 'MonitorDowntimeEndRepeatArgsDict']] end_repeat: A specification of when the Monitor Downtime should end its repeat cycle, by number of occurrences or date.
        :param pulumi.Input[_builtins.str] end_time: A datetime stamp signifying the end of the Monitor Downtime.
        :param pulumi.Input[Union['MonitorDowntimeFrequencyArgs', 'MonitorDowntimeFrequencyArgsDict']] frequency: Configuration options for which days of the month a monitor downtime will occur
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] maintenance_days: A list of maintenance days to be included with the created weekly Monitor Downtime.
        :param pulumi.Input[_builtins.str] mode: An identifier of the type of Monitor Downtime to be created.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] monitor_guids: A list of GUIDs of monitors, to which the created Monitor Downtime shall be applied.
        :param pulumi.Input[_builtins.str] name: A name to identify the Monitor Downtime to be created.
        :param pulumi.Input[_builtins.str] start_time: A datetime stamp signifying the start of the Monitor Downtime.
        :param pulumi.Input[_builtins.str] time_zone: The timezone that applies to the Monitor Downtime schedule.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MonitorDowntimeArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Use this resource to create, update, and delete [Monitor Downtimes](https://docs.newrelic.com/docs/synthetics/synthetic-monitoring/using-monitors/monitor-downtimes-disable-monitoring-during-scheduled-maintenance-times/) in New Relic.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.MonitorDowntime("foo",
            name="Sample Monitor Downtime",
            monitor_guids=[
                "<GUID-1>",
                "<GUID-2>",
            ],
            mode="WEEKLY",
            start_time="2023-11-30T10:30:00",
            end_time="2023-12-10T02:45:30",
            time_zone="Asia/Kolkata",
            end_repeat={
                "on_date": "2023-12-20",
            },
            maintenance_days=[
                "FRIDAY",
                "SATURDAY",
            ])
        ```
        Monitor Downtimes are of four types; **one-time**, **daily**, **weekly** and **monthly**. For more details on each type and the right arguments that go with them, check out the argument reference and examples sections below.

        ## Examples

        ### One-Time Monitor Downtime

        The below example illustrates creating a **one-time** monitor downtime.

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        sample_one_time_newrelic_monitor_downtime = newrelic.MonitorDowntime("sample_one_time_newrelic_monitor_downtime",
            name="Sample One Time Monitor Downtime",
            monitor_guids=[
                "<GUID-1>",
                "<GUID-2>",
            ],
            mode="ONE_TIME",
            start_time="2023-12-04T10:15:00",
            end_time="2024-01-04T16:24:30",
            time_zone="America/Los_Angeles")
        ```

        ### Daily Monitor Downtime

        The below example illustrates creating a **daily** monitor downtime.

        Note that `end_repeat` has been specified in the configuration; however, this is optional, in accordance with the rules of `end_repeat` specified in the argument reference section above. This example uses the `on_date` nested argument of `end_repeat`, however, the other nested argument, `on_repeat` may also be used _instead_, as you may see in some of the other examples below; though both `on_date` and `on_repeat` cannot be specified together, as they are mutually exclusive.

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        sample_daily_newrelic_monitor_downtime = newrelic.MonitorDowntime("sample_daily_newrelic_monitor_downtime",
            name="Sample Daily Monitor Downtime",
            monitor_guids=[
                "<GUID-1>",
                "<GUID-2>",
            ],
            mode="DAILY",
            start_time="2023-12-04T18:15:00",
            end_time="2024-01-04T07:15:00",
            end_repeat={
                "on_date": "2023-12-25",
            },
            time_zone="Asia/Kolkata")
        ```

        ### Weekly Monitor Downtime

        The below example illustrates creating a **weekly** monitor downtime.

        Note that `maintenance_days` has been specified in the configuration as it is required with weekly monitor downtimes; and `end_repeat` has not been specified as it is optional, all in accordance with the rules of these arguments specified in the argument reference section above.

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        sample_weekly_newrelic_monitor_downtime = newrelic.MonitorDowntime("sample_weekly_newrelic_monitor_downtime",
            name="Sample Weekly Monitor Downtime",
            monitor_guids=[
                "<GUID-1>",
                "<GUID-2>",
            ],
            mode="WEEKLY",
            start_time="2023-12-04T14:15:00",
            end_time="2024-01-04T23:55:00",
            time_zone="US/Hawaii",
            maintenance_days=[
                "SATURDAY",
                "SUNDAY",
            ])
        ```

        ### Monthly Monitor Downtime

        The below example illustrates creating a **monthly** monitor downtime.

        Note that `frequency` has been specified in the configuration as it is required with monthly monitor downtimes, and `end_repeat` has been specified too, though it is optional. `frequency` has been specified with `days_of_week` comprising both of its nested arguments, `ordinal_day_of_month` and `week_day`; all in accordance with the rules of these arguments specified in the argument reference section above.

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        sample_monthly_newrelic_monitor_downtime = newrelic.MonitorDowntime("sample_monthly_newrelic_monitor_downtime",
            name="Sample Monthly Monitor Downtime",
            monitor_guids=[
                "<GUID-1>",
                "<GUID-2>",
            ],
            mode="MONTHLY",
            start_time="2023-12-04T07:15:00",
            end_time="2024-01-04T19:15:00",
            end_repeat={
                "on_repeat": 6,
            },
            time_zone="Europe/Dublin",
            frequency={
                "days_of_week": {
                    "ordinal_day_of_month": "SECOND",
                    "week_day": "SATURDAY",
                },
            })
        ```
        However, the `frequency` block in monthly monitor downtimes may also be specified with its other nested argument, `days_of_month`, as shown in the example below - though both `days_of_month` and `days_of_week` cannot be specified together, as they are mutually exclusive.
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        sample_monthly_newrelic_monitor_downtime = newrelic.MonitorDowntime("sample_monthly_newrelic_monitor_downtime",
            name="Sample Monthly Monitor Downtime",
            monitor_guids=[
                "<GUID-1>",
                "<GUID-2>",
            ],
            mode="MONTHLY",
            start_time="2023-12-04T07:15:00",
            end_time="2024-01-04T19:15:00",
            end_repeat={
                "on_repeat": 6,
            },
            time_zone="Europe/Dublin",
            frequency={
                "days_of_months": [
                    3,
                    6,
                    14,
                    23,
                ],
            })
        ```

        ## Import

        A monitor downtime can be imported into Terraform configuration using its `guid`, i.e.

        bash

        ```sh
        $ pulumi import newrelic:index/monitorDowntime:MonitorDowntime monitor <guid>
        ```

        :param str resource_name: The name of the resource.
        :param MonitorDowntimeArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MonitorDowntimeArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 end_repeat: Optional[pulumi.Input[Union['MonitorDowntimeEndRepeatArgs', 'MonitorDowntimeEndRepeatArgsDict']]] = None,
                 end_time: Optional[pulumi.Input[_builtins.str]] = None,
                 frequency: Optional[pulumi.Input[Union['MonitorDowntimeFrequencyArgs', 'MonitorDowntimeFrequencyArgsDict']]] = None,
                 maintenance_days: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 mode: Optional[pulumi.Input[_builtins.str]] = None,
                 monitor_guids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 start_time: Optional[pulumi.Input[_builtins.str]] = None,
                 time_zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MonitorDowntimeArgs.__new__(MonitorDowntimeArgs)

            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["end_repeat"] = end_repeat
            if end_time is None and not opts.urn:
                raise TypeError("Missing required property 'end_time'")
            __props__.__dict__["end_time"] = end_time
            __props__.__dict__["frequency"] = frequency
            __props__.__dict__["maintenance_days"] = maintenance_days
            if mode is None and not opts.urn:
                raise TypeError("Missing required property 'mode'")
            __props__.__dict__["mode"] = mode
            __props__.__dict__["monitor_guids"] = monitor_guids
            __props__.__dict__["name"] = name
            if start_time is None and not opts.urn:
                raise TypeError("Missing required property 'start_time'")
            __props__.__dict__["start_time"] = start_time
            if time_zone is None and not opts.urn:
                raise TypeError("Missing required property 'time_zone'")
            __props__.__dict__["time_zone"] = time_zone
        super(MonitorDowntime, __self__).__init__(
            'newrelic:index/monitorDowntime:MonitorDowntime',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            end_repeat: Optional[pulumi.Input[Union['MonitorDowntimeEndRepeatArgs', 'MonitorDowntimeEndRepeatArgsDict']]] = None,
            end_time: Optional[pulumi.Input[_builtins.str]] = None,
            frequency: Optional[pulumi.Input[Union['MonitorDowntimeFrequencyArgs', 'MonitorDowntimeFrequencyArgsDict']]] = None,
            maintenance_days: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            mode: Optional[pulumi.Input[_builtins.str]] = None,
            monitor_guids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            start_time: Optional[pulumi.Input[_builtins.str]] = None,
            time_zone: Optional[pulumi.Input[_builtins.str]] = None) -> 'MonitorDowntime':
        """
        Get an existing MonitorDowntime resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: The ID of the New Relic account in which the Monitor Downtime shall be created. Defaults to the `account_id` in the provider{} configuration if not specified.
        :param pulumi.Input[Union['MonitorDowntimeEndRepeatArgs', 'MonitorDowntimeEndRepeatArgsDict']] end_repeat: A specification of when the Monitor Downtime should end its repeat cycle, by number of occurrences or date.
        :param pulumi.Input[_builtins.str] end_time: A datetime stamp signifying the end of the Monitor Downtime.
        :param pulumi.Input[Union['MonitorDowntimeFrequencyArgs', 'MonitorDowntimeFrequencyArgsDict']] frequency: Configuration options for which days of the month a monitor downtime will occur
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] maintenance_days: A list of maintenance days to be included with the created weekly Monitor Downtime.
        :param pulumi.Input[_builtins.str] mode: An identifier of the type of Monitor Downtime to be created.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] monitor_guids: A list of GUIDs of monitors, to which the created Monitor Downtime shall be applied.
        :param pulumi.Input[_builtins.str] name: A name to identify the Monitor Downtime to be created.
        :param pulumi.Input[_builtins.str] start_time: A datetime stamp signifying the start of the Monitor Downtime.
        :param pulumi.Input[_builtins.str] time_zone: The timezone that applies to the Monitor Downtime schedule.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MonitorDowntimeState.__new__(_MonitorDowntimeState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["end_repeat"] = end_repeat
        __props__.__dict__["end_time"] = end_time
        __props__.__dict__["frequency"] = frequency
        __props__.__dict__["maintenance_days"] = maintenance_days
        __props__.__dict__["mode"] = mode
        __props__.__dict__["monitor_guids"] = monitor_guids
        __props__.__dict__["name"] = name
        __props__.__dict__["start_time"] = start_time
        __props__.__dict__["time_zone"] = time_zone
        return MonitorDowntime(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the New Relic account in which the Monitor Downtime shall be created. Defaults to the `account_id` in the provider{} configuration if not specified.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="endRepeat")
    def end_repeat(self) -> pulumi.Output[Optional['outputs.MonitorDowntimeEndRepeat']]:
        """
        A specification of when the Monitor Downtime should end its repeat cycle, by number of occurrences or date.
        """
        return pulumi.get(self, "end_repeat")

    @_builtins.property
    @pulumi.getter(name="endTime")
    def end_time(self) -> pulumi.Output[_builtins.str]:
        """
        A datetime stamp signifying the end of the Monitor Downtime.
        """
        return pulumi.get(self, "end_time")

    @_builtins.property
    @pulumi.getter
    def frequency(self) -> pulumi.Output[Optional['outputs.MonitorDowntimeFrequency']]:
        """
        Configuration options for which days of the month a monitor downtime will occur
        """
        return pulumi.get(self, "frequency")

    @_builtins.property
    @pulumi.getter(name="maintenanceDays")
    def maintenance_days(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        A list of maintenance days to be included with the created weekly Monitor Downtime.
        """
        return pulumi.get(self, "maintenance_days")

    @_builtins.property
    @pulumi.getter
    def mode(self) -> pulumi.Output[_builtins.str]:
        """
        An identifier of the type of Monitor Downtime to be created.
        """
        return pulumi.get(self, "mode")

    @_builtins.property
    @pulumi.getter(name="monitorGuids")
    def monitor_guids(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        A list of GUIDs of monitors, to which the created Monitor Downtime shall be applied.
        """
        return pulumi.get(self, "monitor_guids")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        A name to identify the Monitor Downtime to be created.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="startTime")
    def start_time(self) -> pulumi.Output[_builtins.str]:
        """
        A datetime stamp signifying the start of the Monitor Downtime.
        """
        return pulumi.get(self, "start_time")

    @_builtins.property
    @pulumi.getter(name="timeZone")
    def time_zone(self) -> pulumi.Output[_builtins.str]:
        """
        The timezone that applies to the Monitor Downtime schedule.
        """
        return pulumi.get(self, "time_zone")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ApiAccessKeyArgs', 'ApiAccessKey']

@pulumi.input_type
class ApiAccessKeyArgs:
    def __init__(__self__, *,
                 key_type: pulumi.Input[_builtins.str],
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ingest_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notes: Optional[pulumi.Input[_builtins.str]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a ApiAccessKey resource.
        :param pulumi.Input[_builtins.str] key_type: The type of API key to create. Valid options are `INGEST` or `USER` (case-sensitive).
               - If `key_type` is `INGEST`, then `ingest_type` must be specified.
               - If `key_type` is `USER`, then `user_id` must be specified.
        :param pulumi.Input[_builtins.str] account_id: The New Relic account ID where the API access key will be created.
        :param pulumi.Input[_builtins.str] ingest_type: Required if `key_type` is `INGEST`. Valid options are `BROWSER` or `LICENSE` (case-sensitive).
        :param pulumi.Input[_builtins.str] notes: Additional notes about the API access key.
        :param pulumi.Input[_builtins.str] user_id: Required if `key_type` is `USER`. The New Relic user ID for which the API access key will be created.
        """
        pulumi.set(__self__, "key_type", key_type)
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if ingest_type is not None:
            pulumi.set(__self__, "ingest_type", ingest_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if notes is not None:
            pulumi.set(__self__, "notes", notes)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter(name="keyType")
    def key_type(self) -> pulumi.Input[_builtins.str]:
        """
        The type of API key to create. Valid options are `INGEST` or `USER` (case-sensitive).
        - If `key_type` is `INGEST`, then `ingest_type` must be specified.
        - If `key_type` is `USER`, then `user_id` must be specified.
        """
        return pulumi.get(self, "key_type")

    @key_type.setter
    def key_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "key_type", value)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The New Relic account ID where the API access key will be created.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="ingestType")
    def ingest_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Required if `key_type` is `INGEST`. Valid options are `BROWSER` or `LICENSE` (case-sensitive).
        """
        return pulumi.get(self, "ingest_type")

    @ingest_type.setter
    def ingest_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ingest_type", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def notes(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Additional notes about the API access key.
        """
        return pulumi.get(self, "notes")

    @notes.setter
    def notes(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "notes", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Required if `key_type` is `USER`. The New Relic user ID for which the API access key will be created.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_id", value)


@pulumi.input_type
class _ApiAccessKeyState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ingest_type: Optional[pulumi.Input[_builtins.str]] = None,
                 key: Optional[pulumi.Input[_builtins.str]] = None,
                 key_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notes: Optional[pulumi.Input[_builtins.str]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ApiAccessKey resources.
        :param pulumi.Input[_builtins.str] account_id: The New Relic account ID where the API access key will be created.
        :param pulumi.Input[_builtins.str] ingest_type: Required if `key_type` is `INGEST`. Valid options are `BROWSER` or `LICENSE` (case-sensitive).
        :param pulumi.Input[_builtins.str] key: The actual API key.
               - <span style="color:tomato;">It is important to exercise caution when exporting the value of `key`, as it is sensitive information</span>. Avoid logging or exposing it inappropriately.
        :param pulumi.Input[_builtins.str] key_type: The type of API key to create. Valid options are `INGEST` or `USER` (case-sensitive).
               - If `key_type` is `INGEST`, then `ingest_type` must be specified.
               - If `key_type` is `USER`, then `user_id` must be specified.
        :param pulumi.Input[_builtins.str] notes: Additional notes about the API access key.
        :param pulumi.Input[_builtins.str] user_id: Required if `key_type` is `USER`. The New Relic user ID for which the API access key will be created.
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if ingest_type is not None:
            pulumi.set(__self__, "ingest_type", ingest_type)
        if key is not None:
            pulumi.set(__self__, "key", key)
        if key_type is not None:
            pulumi.set(__self__, "key_type", key_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if notes is not None:
            pulumi.set(__self__, "notes", notes)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The New Relic account ID where the API access key will be created.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="ingestType")
    def ingest_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Required if `key_type` is `INGEST`. Valid options are `BROWSER` or `LICENSE` (case-sensitive).
        """
        return pulumi.get(self, "ingest_type")

    @ingest_type.setter
    def ingest_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ingest_type", value)

    @_builtins.property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The actual API key.
        - <span style="color:tomato;">It is important to exercise caution when exporting the value of `key`, as it is sensitive information</span>. Avoid logging or exposing it inappropriately.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "key", value)

    @_builtins.property
    @pulumi.getter(name="keyType")
    def key_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of API key to create. Valid options are `INGEST` or `USER` (case-sensitive).
        - If `key_type` is `INGEST`, then `ingest_type` must be specified.
        - If `key_type` is `USER`, then `user_id` must be specified.
        """
        return pulumi.get(self, "key_type")

    @key_type.setter
    def key_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "key_type", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def notes(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Additional notes about the API access key.
        """
        return pulumi.get(self, "notes")

    @notes.setter
    def notes(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "notes", value)

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Required if `key_type` is `USER`. The New Relic user ID for which the API access key will be created.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_id", value)


@pulumi.type_token("newrelic:index/apiAccessKey:ApiAccessKey")
class ApiAccessKey(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ingest_type: Optional[pulumi.Input[_builtins.str]] = None,
                 key_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notes: Optional[pulumi.Input[_builtins.str]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Import

        Existing API access keys can be imported using a composite ID of `<api_access_key_id>:<key_type>`, where `<key_type>` is either `INGEST` or `USER`. Refer to the considerations listed in the Important Considerations section above regarding limitations on importing the actual key value.

        For example:

        ```sh
        $ pulumi import newrelic:index/apiAccessKey:ApiAccessKey foobar "131313133A331313130B5F13DF01313FDB13B13133EE5E133D13EAAB3A3C13D3:INGEST"
        ```

        For customers using Terraform v1.5 and above, it is recommended to use the `import {}` block in your Terraform configuration. This allows Terraform to generate the resource configuration automatically during the import process by running a `pulumi preview -generate-config-out=<filename>.tf`, reducing manual effort and ensuring accuracy.

        For example:

        hcl

        import {

          id = "131313133A331313130B5F13DF01313FDB13B13133EE5E133D13EAAB3A3C13D3:INGEST"

          to = newrelic_api_access_key.foobar

        }

        This approach simplifies the import process and ensures that the resource configuration aligns with the imported state.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: The New Relic account ID where the API access key will be created.
        :param pulumi.Input[_builtins.str] ingest_type: Required if `key_type` is `INGEST`. Valid options are `BROWSER` or `LICENSE` (case-sensitive).
        :param pulumi.Input[_builtins.str] key_type: The type of API key to create. Valid options are `INGEST` or `USER` (case-sensitive).
               - If `key_type` is `INGEST`, then `ingest_type` must be specified.
               - If `key_type` is `USER`, then `user_id` must be specified.
        :param pulumi.Input[_builtins.str] notes: Additional notes about the API access key.
        :param pulumi.Input[_builtins.str] user_id: Required if `key_type` is `USER`. The New Relic user ID for which the API access key will be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ApiAccessKeyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        Existing API access keys can be imported using a composite ID of `<api_access_key_id>:<key_type>`, where `<key_type>` is either `INGEST` or `USER`. Refer to the considerations listed in the Important Considerations section above regarding limitations on importing the actual key value.

        For example:

        ```sh
        $ pulumi import newrelic:index/apiAccessKey:ApiAccessKey foobar "131313133A331313130B5F13DF01313FDB13B13133EE5E133D13EAAB3A3C13D3:INGEST"
        ```

        For customers using Terraform v1.5 and above, it is recommended to use the `import {}` block in your Terraform configuration. This allows Terraform to generate the resource configuration automatically during the import process by running a `pulumi preview -generate-config-out=<filename>.tf`, reducing manual effort and ensuring accuracy.

        For example:

        hcl

        import {

          id = "131313133A331313130B5F13DF01313FDB13B13133EE5E133D13EAAB3A3C13D3:INGEST"

          to = newrelic_api_access_key.foobar

        }

        This approach simplifies the import process and ensures that the resource configuration aligns with the imported state.

        :param str resource_name: The name of the resource.
        :param ApiAccessKeyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ApiAccessKeyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ingest_type: Optional[pulumi.Input[_builtins.str]] = None,
                 key_type: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notes: Optional[pulumi.Input[_builtins.str]] = None,
                 user_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ApiAccessKeyArgs.__new__(ApiAccessKeyArgs)

            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["ingest_type"] = ingest_type
            if key_type is None and not opts.urn:
                raise TypeError("Missing required property 'key_type'")
            __props__.__dict__["key_type"] = key_type
            __props__.__dict__["name"] = name
            __props__.__dict__["notes"] = notes
            __props__.__dict__["user_id"] = user_id
            __props__.__dict__["key"] = None
        super(ApiAccessKey, __self__).__init__(
            'newrelic:index/apiAccessKey:ApiAccessKey',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            ingest_type: Optional[pulumi.Input[_builtins.str]] = None,
            key: Optional[pulumi.Input[_builtins.str]] = None,
            key_type: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            notes: Optional[pulumi.Input[_builtins.str]] = None,
            user_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'ApiAccessKey':
        """
        Get an existing ApiAccessKey resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: The New Relic account ID where the API access key will be created.
        :param pulumi.Input[_builtins.str] ingest_type: Required if `key_type` is `INGEST`. Valid options are `BROWSER` or `LICENSE` (case-sensitive).
        :param pulumi.Input[_builtins.str] key: The actual API key.
               - <span style="color:tomato;">It is important to exercise caution when exporting the value of `key`, as it is sensitive information</span>. Avoid logging or exposing it inappropriately.
        :param pulumi.Input[_builtins.str] key_type: The type of API key to create. Valid options are `INGEST` or `USER` (case-sensitive).
               - If `key_type` is `INGEST`, then `ingest_type` must be specified.
               - If `key_type` is `USER`, then `user_id` must be specified.
        :param pulumi.Input[_builtins.str] notes: Additional notes about the API access key.
        :param pulumi.Input[_builtins.str] user_id: Required if `key_type` is `USER`. The New Relic user ID for which the API access key will be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ApiAccessKeyState.__new__(_ApiAccessKeyState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["ingest_type"] = ingest_type
        __props__.__dict__["key"] = key
        __props__.__dict__["key_type"] = key_type
        __props__.__dict__["name"] = name
        __props__.__dict__["notes"] = notes
        __props__.__dict__["user_id"] = user_id
        return ApiAccessKey(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The New Relic account ID where the API access key will be created.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="ingestType")
    def ingest_type(self) -> pulumi.Output[_builtins.str]:
        """
        Required if `key_type` is `INGEST`. Valid options are `BROWSER` or `LICENSE` (case-sensitive).
        """
        return pulumi.get(self, "ingest_type")

    @_builtins.property
    @pulumi.getter
    def key(self) -> pulumi.Output[_builtins.str]:
        """
        The actual API key.
        - <span style="color:tomato;">It is important to exercise caution when exporting the value of `key`, as it is sensitive information</span>. Avoid logging or exposing it inappropriately.
        """
        return pulumi.get(self, "key")

    @_builtins.property
    @pulumi.getter(name="keyType")
    def key_type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of API key to create. Valid options are `INGEST` or `USER` (case-sensitive).
        - If `key_type` is `INGEST`, then `ingest_type` must be specified.
        - If `key_type` is `USER`, then `user_id` must be specified.
        """
        return pulumi.get(self, "key_type")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def notes(self) -> pulumi.Output[_builtins.str]:
        """
        Additional notes about the API access key.
        """
        return pulumi.get(self, "notes")

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[_builtins.str]:
        """
        Required if `key_type` is `USER`. The New Relic user ID for which the API access key will be created.
        """
        return pulumi.get(self, "user_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['PipelineCloudRuleArgs', 'PipelineCloudRule']

@pulumi.input_type
class PipelineCloudRuleArgs:
    def __init__(__self__, *,
                 nrql: pulumi.Input[_builtins.str],
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a PipelineCloudRule resource.
        :param pulumi.Input[_builtins.str] nrql: The NRQL query that defines the data to be processed by this Pipeline Cloud Rule.
        :param pulumi.Input[_builtins.str] account_id: The account ID where the Pipeline Cloud Rule will be created.
        :param pulumi.Input[_builtins.str] description: Additional information about the rule.
        :param pulumi.Input[_builtins.str] name: The name of the rule. This must be unique within an account.
        """
        pulumi.set(__self__, "nrql", nrql)
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def nrql(self) -> pulumi.Input[_builtins.str]:
        """
        The NRQL query that defines the data to be processed by this Pipeline Cloud Rule.
        """
        return pulumi.get(self, "nrql")

    @nrql.setter
    def nrql(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "nrql", value)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The account ID where the Pipeline Cloud Rule will be created.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Additional information about the rule.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the rule. This must be unique within an account.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _PipelineCloudRuleState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 nrql: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering PipelineCloudRule resources.
        :param pulumi.Input[_builtins.str] account_id: The account ID where the Pipeline Cloud Rule will be created.
        :param pulumi.Input[_builtins.str] description: Additional information about the rule.
        :param pulumi.Input[_builtins.str] name: The name of the rule. This must be unique within an account.
        :param pulumi.Input[_builtins.str] nrql: The NRQL query that defines the data to be processed by this Pipeline Cloud Rule.
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if nrql is not None:
            pulumi.set(__self__, "nrql", nrql)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The account ID where the Pipeline Cloud Rule will be created.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Additional information about the rule.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the rule. This must be unique within an account.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def nrql(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The NRQL query that defines the data to be processed by this Pipeline Cloud Rule.
        """
        return pulumi.get(self, "nrql")

    @nrql.setter
    def nrql(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "nrql", value)


@pulumi.type_token("newrelic:index/pipelineCloudRule:PipelineCloudRule")
class PipelineCloudRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 nrql: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.PipelineCloudRule("foo",
            account_id="1000100",
            name="Test Pipeline Cloud Rule",
            description="This rule deletes all DEBUG logs from the dev environment.",
            nrql="DELETE FROM Log WHERE logLevel = 'DEBUG' AND environment = 'dev'")
        ```

        ## Import

        Pipeline Cloud Rules can be imported using the `id`. For example:

        bash

        ```sh
        $ pulumi import newrelic:index/pipelineCloudRule:PipelineCloudRule foo <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: The account ID where the Pipeline Cloud Rule will be created.
        :param pulumi.Input[_builtins.str] description: Additional information about the rule.
        :param pulumi.Input[_builtins.str] name: The name of the rule. This must be unique within an account.
        :param pulumi.Input[_builtins.str] nrql: The NRQL query that defines the data to be processed by this Pipeline Cloud Rule.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PipelineCloudRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.PipelineCloudRule("foo",
            account_id="1000100",
            name="Test Pipeline Cloud Rule",
            description="This rule deletes all DEBUG logs from the dev environment.",
            nrql="DELETE FROM Log WHERE logLevel = 'DEBUG' AND environment = 'dev'")
        ```

        ## Import

        Pipeline Cloud Rules can be imported using the `id`. For example:

        bash

        ```sh
        $ pulumi import newrelic:index/pipelineCloudRule:PipelineCloudRule foo <id>
        ```

        :param str resource_name: The name of the resource.
        :param PipelineCloudRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PipelineCloudRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 nrql: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PipelineCloudRuleArgs.__new__(PipelineCloudRuleArgs)

            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            if nrql is None and not opts.urn:
                raise TypeError("Missing required property 'nrql'")
            __props__.__dict__["nrql"] = nrql
        super(PipelineCloudRule, __self__).__init__(
            'newrelic:index/pipelineCloudRule:PipelineCloudRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            nrql: Optional[pulumi.Input[_builtins.str]] = None) -> 'PipelineCloudRule':
        """
        Get an existing PipelineCloudRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: The account ID where the Pipeline Cloud Rule will be created.
        :param pulumi.Input[_builtins.str] description: Additional information about the rule.
        :param pulumi.Input[_builtins.str] name: The name of the rule. This must be unique within an account.
        :param pulumi.Input[_builtins.str] nrql: The NRQL query that defines the data to be processed by this Pipeline Cloud Rule.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PipelineCloudRuleState.__new__(_PipelineCloudRuleState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["nrql"] = nrql
        return PipelineCloudRule(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[_builtins.str]:
        """
        The account ID where the Pipeline Cloud Rule will be created.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Additional information about the rule.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the rule. This must be unique within an account.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def nrql(self) -> pulumi.Output[_builtins.str]:
        """
        The NRQL query that defines the data to be processed by this Pipeline Cloud Rule.
        """
        return pulumi.get(self, "nrql")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['NrqlDropRuleArgs', 'NrqlDropRule']

@pulumi.input_type
class NrqlDropRuleArgs:
    def __init__(__self__, *,
                 action: pulumi.Input[_builtins.str],
                 nrql: pulumi.Input[_builtins.str],
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a NrqlDropRule resource.
        :param pulumi.Input[_builtins.str] action: An action type specifying how to apply the NRQL string (either `drop_data`, `drop_attributes`, or ` drop_attributes_from_metric_aggregates`).
        :param pulumi.Input[_builtins.str] nrql: A NRQL string that specifies what data types to drop.
        :param pulumi.Input[_builtins.str] account_id: Account where the drop rule will be put. Defaults to the account associated with the API key used.
        :param pulumi.Input[_builtins.str] description: The description of the drop rule.
        """
        pulumi.set(__self__, "action", action)
        pulumi.set(__self__, "nrql", nrql)
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @_builtins.property
    @pulumi.getter
    def action(self) -> pulumi.Input[_builtins.str]:
        """
        An action type specifying how to apply the NRQL string (either `drop_data`, `drop_attributes`, or ` drop_attributes_from_metric_aggregates`).
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "action", value)

    @_builtins.property
    @pulumi.getter
    def nrql(self) -> pulumi.Input[_builtins.str]:
        """
        A NRQL string that specifies what data types to drop.
        """
        return pulumi.get(self, "nrql")

    @nrql.setter
    def nrql(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "nrql", value)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Account where the drop rule will be put. Defaults to the account associated with the API key used.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the drop rule.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class _NrqlDropRuleState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 action: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 nrql: Optional[pulumi.Input[_builtins.str]] = None,
                 pipeline_cloud_rule_entity_id: Optional[pulumi.Input[_builtins.str]] = None,
                 rule_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering NrqlDropRule resources.
        :param pulumi.Input[_builtins.str] account_id: Account where the drop rule will be put. Defaults to the account associated with the API key used.
        :param pulumi.Input[_builtins.str] action: An action type specifying how to apply the NRQL string (either `drop_data`, `drop_attributes`, or ` drop_attributes_from_metric_aggregates`).
        :param pulumi.Input[_builtins.str] description: The description of the drop rule.
        :param pulumi.Input[_builtins.str] nrql: A NRQL string that specifies what data types to drop.
        :param pulumi.Input[_builtins.str] pipeline_cloud_rule_entity_id: The ID (GUID) of the corresponding Pipeline Cloud Rule, (migrated upstream by New Relic, in light of the upcoming EOL, as stated in the Deprecation Warning above). This can be used to import the corresponding Pipeline Cloud Rule as a [`PipelineCloudRule`](https://www.terraform.io/providers/newrelic/newrelic/latest/docs/resources/pipeline_cloud_rule) resource, as explained in our Drop Rules EOL Migration Guide.
        :param pulumi.Input[_builtins.str] rule_id: The id, uniquely identifying the rule.
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if action is not None:
            pulumi.set(__self__, "action", action)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if nrql is not None:
            pulumi.set(__self__, "nrql", nrql)
        if pipeline_cloud_rule_entity_id is not None:
            pulumi.set(__self__, "pipeline_cloud_rule_entity_id", pipeline_cloud_rule_entity_id)
        if rule_id is not None:
            pulumi.set(__self__, "rule_id", rule_id)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Account where the drop rule will be put. Defaults to the account associated with the API key used.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter
    def action(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        An action type specifying how to apply the NRQL string (either `drop_data`, `drop_attributes`, or ` drop_attributes_from_metric_aggregates`).
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "action", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the drop rule.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def nrql(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A NRQL string that specifies what data types to drop.
        """
        return pulumi.get(self, "nrql")

    @nrql.setter
    def nrql(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "nrql", value)

    @_builtins.property
    @pulumi.getter(name="pipelineCloudRuleEntityId")
    def pipeline_cloud_rule_entity_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID (GUID) of the corresponding Pipeline Cloud Rule, (migrated upstream by New Relic, in light of the upcoming EOL, as stated in the Deprecation Warning above). This can be used to import the corresponding Pipeline Cloud Rule as a [`PipelineCloudRule`](https://www.terraform.io/providers/newrelic/newrelic/latest/docs/resources/pipeline_cloud_rule) resource, as explained in our Drop Rules EOL Migration Guide.
        """
        return pulumi.get(self, "pipeline_cloud_rule_entity_id")

    @pipeline_cloud_rule_entity_id.setter
    def pipeline_cloud_rule_entity_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pipeline_cloud_rule_entity_id", value)

    @_builtins.property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The id, uniquely identifying the rule.
        """
        return pulumi.get(self, "rule_id")

    @rule_id.setter
    def rule_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "rule_id", value)


@pulumi.type_token("newrelic:index/nrqlDropRule:NrqlDropRule")
class NrqlDropRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 action: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 nrql: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Import

        New Relic NRQL drop rules can be imported using a concatenated string of the format

         `<account_id>:<rule_id>`, e.g.

        bash

        ```sh
        $ pulumi import newrelic:index/nrqlDropRule:NrqlDropRule foo 12345:34567
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Account where the drop rule will be put. Defaults to the account associated with the API key used.
        :param pulumi.Input[_builtins.str] action: An action type specifying how to apply the NRQL string (either `drop_data`, `drop_attributes`, or ` drop_attributes_from_metric_aggregates`).
        :param pulumi.Input[_builtins.str] description: The description of the drop rule.
        :param pulumi.Input[_builtins.str] nrql: A NRQL string that specifies what data types to drop.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NrqlDropRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        New Relic NRQL drop rules can be imported using a concatenated string of the format

         `<account_id>:<rule_id>`, e.g.

        bash

        ```sh
        $ pulumi import newrelic:index/nrqlDropRule:NrqlDropRule foo 12345:34567
        ```

        :param str resource_name: The name of the resource.
        :param NrqlDropRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NrqlDropRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 action: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 nrql: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NrqlDropRuleArgs.__new__(NrqlDropRuleArgs)

            __props__.__dict__["account_id"] = account_id
            if action is None and not opts.urn:
                raise TypeError("Missing required property 'action'")
            __props__.__dict__["action"] = action
            __props__.__dict__["description"] = description
            if nrql is None and not opts.urn:
                raise TypeError("Missing required property 'nrql'")
            __props__.__dict__["nrql"] = nrql
            __props__.__dict__["pipeline_cloud_rule_entity_id"] = None
            __props__.__dict__["rule_id"] = None
        super(NrqlDropRule, __self__).__init__(
            'newrelic:index/nrqlDropRule:NrqlDropRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            action: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            nrql: Optional[pulumi.Input[_builtins.str]] = None,
            pipeline_cloud_rule_entity_id: Optional[pulumi.Input[_builtins.str]] = None,
            rule_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'NrqlDropRule':
        """
        Get an existing NrqlDropRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Account where the drop rule will be put. Defaults to the account associated with the API key used.
        :param pulumi.Input[_builtins.str] action: An action type specifying how to apply the NRQL string (either `drop_data`, `drop_attributes`, or ` drop_attributes_from_metric_aggregates`).
        :param pulumi.Input[_builtins.str] description: The description of the drop rule.
        :param pulumi.Input[_builtins.str] nrql: A NRQL string that specifies what data types to drop.
        :param pulumi.Input[_builtins.str] pipeline_cloud_rule_entity_id: The ID (GUID) of the corresponding Pipeline Cloud Rule, (migrated upstream by New Relic, in light of the upcoming EOL, as stated in the Deprecation Warning above). This can be used to import the corresponding Pipeline Cloud Rule as a [`PipelineCloudRule`](https://www.terraform.io/providers/newrelic/newrelic/latest/docs/resources/pipeline_cloud_rule) resource, as explained in our Drop Rules EOL Migration Guide.
        :param pulumi.Input[_builtins.str] rule_id: The id, uniquely identifying the rule.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NrqlDropRuleState.__new__(_NrqlDropRuleState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["action"] = action
        __props__.__dict__["description"] = description
        __props__.__dict__["nrql"] = nrql
        __props__.__dict__["pipeline_cloud_rule_entity_id"] = pipeline_cloud_rule_entity_id
        __props__.__dict__["rule_id"] = rule_id
        return NrqlDropRule(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[_builtins.str]:
        """
        Account where the drop rule will be put. Defaults to the account associated with the API key used.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter
    def action(self) -> pulumi.Output[_builtins.str]:
        """
        An action type specifying how to apply the NRQL string (either `drop_data`, `drop_attributes`, or ` drop_attributes_from_metric_aggregates`).
        """
        return pulumi.get(self, "action")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The description of the drop rule.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def nrql(self) -> pulumi.Output[_builtins.str]:
        """
        A NRQL string that specifies what data types to drop.
        """
        return pulumi.get(self, "nrql")

    @_builtins.property
    @pulumi.getter(name="pipelineCloudRuleEntityId")
    def pipeline_cloud_rule_entity_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID (GUID) of the corresponding Pipeline Cloud Rule, (migrated upstream by New Relic, in light of the upcoming EOL, as stated in the Deprecation Warning above). This can be used to import the corresponding Pipeline Cloud Rule as a [`PipelineCloudRule`](https://www.terraform.io/providers/newrelic/newrelic/latest/docs/resources/pipeline_cloud_rule) resource, as explained in our Drop Rules EOL Migration Guide.
        """
        return pulumi.get(self, "pipeline_cloud_rule_entity_id")

    @_builtins.property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> pulumi.Output[_builtins.str]:
        """
        The id, uniquely identifying the rule.
        """
        return pulumi.get(self, "rule_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetUserResult',
    'AwaitableGetUserResult',
    'get_user',
    'get_user_output',
]

@pulumi.output_type
class GetUserResult:
    """
    A collection of values returned by getUser.
    """
    def __init__(__self__, authentication_domain_id=None, email_id=None, id=None, name=None):
        if authentication_domain_id and not isinstance(authentication_domain_id, str):
            raise TypeError("Expected argument 'authentication_domain_id' to be a str")
        pulumi.set(__self__, "authentication_domain_id", authentication_domain_id)
        if email_id and not isinstance(email_id, str):
            raise TypeError("Expected argument 'email_id' to be a str")
        pulumi.set(__self__, "email_id", email_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="authenticationDomainId")
    def authentication_domain_id(self) -> _builtins.str:
        return pulumi.get(self, "authentication_domain_id")

    @_builtins.property
    @pulumi.getter(name="emailId")
    def email_id(self) -> _builtins.str:
        return pulumi.get(self, "email_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of the matching user fetched.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")


class AwaitableGetUserResult(GetUserResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUserResult(
            authentication_domain_id=self.authentication_domain_id,
            email_id=self.email_id,
            id=self.id,
            name=self.name)


def get_user(authentication_domain_id: Optional[_builtins.str] = None,
             email_id: Optional[_builtins.str] = None,
             name: Optional[_builtins.str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUserResult:
    """
    The `User` data source helps search for a user by their name and/or email ID, and accordingly, fetch the ID of the matching user.

    ## Example Usage

    The below example illustrates fetching a the ID of a user (and other arguments) using the ID of the authentication domain the user belongs to, as well as a name and/or email ID, which can be used as criteria to search for a user who matches these specified parameters.
    ```python
    import pulumi
    import pulumi_newrelic as newrelic

    foo = newrelic.get_authentication_domain(name="Test Authentication Domain")
    user_one = newrelic.get_user(authentication_domain_id=foo.id,
        name="Test User")
    user_two = newrelic.get_user(authentication_domain_id=foo.id,
        email_id="test_user@random.com")
    ```


    :param _builtins.str authentication_domain_id: The ID of the authentication domain the user to be searched for belongs to.
    :param _builtins.str email_id: The email ID of the user to search for.
           
           It should be noted that either `name` or `email_id` must be specified in order to retrieve a matching user.
           
           > **NOTE** If the `name` specified in the configuration matches the names of multiple users in the account, the data source will return the first match from the list of all matching users retrieved from the API. However, when using the `email_id` argument as the search criterion, only the user with the specified email ID will be returned, as each user has a unique email ID and multiple users cannot have the same email ID.
           
           > **NOTE** The ID of an authentication domain can be retrieved using its name, via the data source `get_authentication_domain`, as shown in the example above. Head over to the documentation of this data source for more details and examples.
    :param _builtins.str name: The name of the user to search for.
    """
    __args__ = dict()
    __args__['authenticationDomainId'] = authentication_domain_id
    __args__['emailId'] = email_id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('newrelic:index/getUser:getUser', __args__, opts=opts, typ=GetUserResult).value

    return AwaitableGetUserResult(
        authentication_domain_id=pulumi.get(__ret__, 'authentication_domain_id'),
        email_id=pulumi.get(__ret__, 'email_id'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'))
def get_user_output(authentication_domain_id: Optional[pulumi.Input[_builtins.str]] = None,
                    email_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetUserResult]:
    """
    The `User` data source helps search for a user by their name and/or email ID, and accordingly, fetch the ID of the matching user.

    ## Example Usage

    The below example illustrates fetching a the ID of a user (and other arguments) using the ID of the authentication domain the user belongs to, as well as a name and/or email ID, which can be used as criteria to search for a user who matches these specified parameters.
    ```python
    import pulumi
    import pulumi_newrelic as newrelic

    foo = newrelic.get_authentication_domain(name="Test Authentication Domain")
    user_one = newrelic.get_user(authentication_domain_id=foo.id,
        name="Test User")
    user_two = newrelic.get_user(authentication_domain_id=foo.id,
        email_id="test_user@random.com")
    ```


    :param _builtins.str authentication_domain_id: The ID of the authentication domain the user to be searched for belongs to.
    :param _builtins.str email_id: The email ID of the user to search for.
           
           It should be noted that either `name` or `email_id` must be specified in order to retrieve a matching user.
           
           > **NOTE** If the `name` specified in the configuration matches the names of multiple users in the account, the data source will return the first match from the list of all matching users retrieved from the API. However, when using the `email_id` argument as the search criterion, only the user with the specified email ID will be returned, as each user has a unique email ID and multiple users cannot have the same email ID.
           
           > **NOTE** The ID of an authentication domain can be retrieved using its name, via the data source `get_authentication_domain`, as shown in the example above. Head over to the documentation of this data source for more details and examples.
    :param _builtins.str name: The name of the user to search for.
    """
    __args__ = dict()
    __args__['authenticationDomainId'] = authentication_domain_id
    __args__['emailId'] = email_id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('newrelic:index/getUser:getUser', __args__, opts=opts, typ=GetUserResult)
    return __ret__.apply(lambda __response__: GetUserResult(
        authentication_domain_id=pulumi.get(__response__, 'authentication_domain_id'),
        email_id=pulumi.get(__response__, 'email_id'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name')))
